@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1301';
+our $VERSION = '0.1302';
 
 use Moo;
 use strictures 2;
@@ -80,12 +80,14 @@ has tuning => (
 
 has horiz => (
     is      => 'ro',
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
 
 has image => (
     is      => 'ro',
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
@@ -116,6 +118,7 @@ has showname => (
 
 has verbose => (
     is      => 'ro',
+    isa     => \&_boolean,
     default => sub { 0 },
 );
 
@@ -526,7 +529,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1301
+version 0.1302
 
 =head1 SYNOPSIS
 
@@ -550,7 +553,7 @@ version 0.1301
     verbose  => 1,
   );
 
-  $dia->chord('xx0232');          # set a new chord
+  $dia->chord('x02220');          # set a new chord
   $dia->position(1);              # set a new position
   $dia->outfile('mystery-chord'); # set a new filename
   $dia->showname('Xb dim');       # "X flat diminished"
